==> haskell-sdl2-ttf-2.1.3-268.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   sdl2-ttf
version:                2.1.3
visibility:             public
id:                     sdl2-ttf-2.1.3-LofidsyCGwV9uzPsytmcrX
key:                    sdl2-ttf-2.1.3-LofidsyCGwV9uzPsytmcrX
license:                BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:             Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:               Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:               Font, Foreign binding, Graphics
abi:                    3690ba4b44f333ed7ce74a0d29b9b59f
exposed:                True
exposed-modules:        SDL.Font SDL.Raw.Font
hidden-modules:         SDL.Raw.Helper
import-dirs:            /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-sdl2-ttf
hs-libraries:           HSsdl2-ttf-2.1.3-LofidsyCGwV9uzPsytmcrX
extra-libraries:        SDL2_ttf SDL2
extra-libraries-static:
    SDL2_ttf SDL2 harfbuzz m glib-2.0 m sysprof-capture-4 pcre2-8
    pthread graphite2 freetype dl bz2 png16 m m z brotlidec
    brotlicommon

include-dirs:
    /usr/include/SDL2 /usr/include /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6 /usr/include/freetype2 /usr/include/libpng16

depends:
    base-4.18.2.1 bytestring-0.11.5.3
    sdl2-2.5.5.1-8WpHeHy9obGJ642iotZCvW template-haskell-2.20.0.0
    text-2.0.2 th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:           /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sdl2-ttf-2.1.3-269-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   sdl2-ttf
version:                2.1.3
visibility:             public
id:                     sdl2-ttf-2.1.3-8B6uC3AECU71TXftTM9Wud
key:                    sdl2-ttf-2.1.3-8B6uC3AECU71TXftTM9Wud
license:                BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:             Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:               Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:               Font, Foreign binding, Graphics
abi:                    ffb65d4c0a7eb3f951e4c4a6de16c154
exposed:                True
exposed-modules:        SDL.Font SDL.Raw.Font
hidden-modules:         SDL.Raw.Helper
import-dirs:            /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/sdl2-ttf-2.1.3 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-sdl2-ttf
hs-libraries:           HSsdl2-ttf-2.1.3-8B6uC3AECU71TXftTM9Wud
extra-libraries:        SDL2_ttf SDL2
extra-libraries-static:
    SDL2_ttf SDL2 harfbuzz m glib-2.0 atomic m sysprof-capture-4
    pcre2-8 pthread graphite2 freetype dl bz2 png16 m m z brotlidec
    brotlicommon

include-dirs:
    /usr/include/SDL2 /usr/include /usr/include/harfbuzz
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6 /usr/include/freetype2 /usr/include/libpng16

depends:
    base-4.18.2.1 bytestring-0.11.5.3
    sdl2-2.5.5.1-DGS2PBBCpbo87pbtvrrfIF template-haskell-2.20.0.0
    text-2.0.2 th-abstraction-0.5.0.0-HAFjiAO2nGN58SdxVZCnLH
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:           /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
